class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

def info(text):
    print(text)
def warn(text):
    print(bcolors.WARNING+text+bcolors.ENDC)
def success(text):
    print(bcolors.OKGREEN+text+bcolors.ENDC)
def error_and_quit(text):
    print(bcolors.FAIL + text + bcolors.ENDC)
    raise SystemExit(1)